@@ -141,7 +141,7 @@ function set_loop_tag($data, $page, &$looptag)
            /* 롼ץͤ */
            $looptag[$k]["<<LOG_DATE>>"] = $log_date;
            $looptag[$k]["<<LOG_HOST>>"] = $log_host;
-           $looptag[$k]["<<LOG_MESSAGE>>"] = $log_message;
+           $looptag[$k]["<<LOG_MESSAGE>>"] = str_replace(" ", "&nbsp", $log_message);
            $k++;
        }
 
