@@ -525,46 +525,23 @@ function check_mail_search_condition($post)
         return FALSE;
     }
 
-    /*ϤȽλå*/
+    /* ϤȽλå */
+    $start = "";
+    $end   = "";
 
-    /*λǯꤵƤʤȤ*/
-    if ($end_arr[0] === "--") {
-        /*ǯ*/
-        $end_arr[0] = date("Y");
-    }
-
-    /*ꤵƤʤ*/
-    if ($end_arr[1] === "--") {
-        $end_arr[1] = 12;
-    }
-
-    /*ꤵƤʤ*/
-    if ($end_arr[2] === "--") {
-        $end_arr[2] = date("t", strtotime($end_arr[0]. "-" .$end_arr[1]));
-    }
-
-    /*ꤵƤʤ*/
-    if ($end_arr[3] === "--") {
-        $end_arr[3] = 23;
-    }
-
-    /*ʬꤵƤʤ*/
-    if ($end_arr[4] === "--") {
-        $end_arr[4] = 59;
-    }
-
-    /*äꤵƤʤ*/
-    if ($end_arr[5] === "--") {
-        $end_arr[5] = 59;
-    }
-        
-    $start = sprintf("%04d%02d%02d%02d%02d%02d", $start_arr[0], $start_arr[1], $start_arr[2], $start_arr[3], $start_arr[4], $start_arr[5]);
-    $end = sprintf("%04d%02d%02d%02d%02d%02d", $end_arr[0], $end_arr[1], $end_arr[2], $end_arr[3], $end_arr[4], $end_arr[5]);
+    set_default_time($start_arr, $end_arr, $start, $end);
 
     if ($start > $end) {
         $err_msg = $msgarr['28018'][SCREEN_MSG];
+        $log_msg = $msgarr['28018'][LOG_MSG];
         return FALSE;
     }
+
+    $ret = check_duration($start_arr, $end_arr);
+    if ($ret === FALSE) {
+        return FALSE;
+    }
+
     return TRUE;
 }
 
